==> v0.3.1.zip: BlinkenMovie.h <==
/* BlinkenLib
 * version 0.3.1 date 2005-03-05
 * Copyright 2004-2005 Stefan Schuermans <1stein@schuermans.info>
 * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
 * a blinkenarea.org project
 * powered by eventphone.de
 */

#ifndef INC_BlinkenMovie
#define INC_BlinkenMovie

#include "BlinkenFrame.h"

typedef struct sBlinkenMovie stBlinkenMovie;

stBlinkenMovie * BlinkenMovieNew( int height, int width, int channels, int maxval );

stBlinkenMovie * BlinkenMovieClone( stBlinkenMovie * pSrcMovie );

void BlinkenMovieFree( stBlinkenMovie * pMovie );

int BlinkenMovieGetHeight( stBlinkenMovie * pMovie );
int BlinkenMovieGetWidth( stBlinkenMovie * pMovie );
int BlinkenMovieGetChannels( stBlinkenMovie * pMovie );
int BlinkenMovieGetMaxval( stBlinkenMovie * pMovie );
int BlinkenMovieGetDuration( stBlinkenMovie * pMovie );

int BlinkenMovieGetInfoCnt( stBlinkenMovie * pMovie );
char * BlinkenMovieGetInfoType( stBlinkenMovie * pMovie, int infoNo );
char * BlinkenMovieGetInfoData( stBlinkenMovie * pMovie, int infoNo );
void BlinkenMovieSetInfo( stBlinkenMovie * pMovie, int infoNo, char * pInfoType, char * pInfoData );
void BlinkenMovieInsertInfo( stBlinkenMovie * pMovie, int infoNo, char * pInfoType, char * pInfoData );
void BlinkenMovieAppendInfo( stBlinkenMovie * pMovie, char * pInfoType, char * pInfoData );
void BlinkenMovieDeleteInfo( stBlinkenMovie * pMovie, int infoNo );
void BlinkenMovieDeleteInfos( stBlinkenMovie * pMovie );

int BlinkenMovieGetFrameCnt( stBlinkenMovie * pMovie );
stBlinkenFrame * BlinkenMovieGetFrame( stBlinkenMovie * pMovie, int frameNo );
void BlinkenMovieSetFrame( stBlinkenMovie * pMovie, int frameNo, stBlinkenFrame * pFrame );
int BlinkenMovieInsertFrame( stBlinkenMovie * pMovie, int frameNo, stBlinkenFrame * pFrame );
int BlinkenMovieAppendFrame( stBlinkenMovie * pMovie, stBlinkenFrame * pFrame );
void BlinkenMovieDeleteFrame( stBlinkenMovie * pMovie, int frameNo );
void BlinkenMovieDeleteFrames( stBlinkenMovie * pMovie );

void BlinkenMovieResize( stBlinkenMovie * pMovie, int height, int width, int channels, int maxval );
void BlinkenMovieScale( stBlinkenMovie * pMovie, int height, int width );

char * BlinkenMovieToString( stBlinkenMovie * pMovie );

stBlinkenMovie * BlinkenMovieLoadBlm( char * pFilename );
stBlinkenMovie * BlinkenMovieLoadBmm( char * pFilename );
stBlinkenMovie * BlinkenMovieLoadBml( char * pFilename );
stBlinkenMovie * BlinkenMovieLoadBbm( char * pFilename );
stBlinkenMovie * BlinkenMovieLoad( char * pFilename );

int BlinkenMovieSaveBlm( stBlinkenMovie * pMovie, char * pFilename );
int BlinkenMovieSaveBmm( stBlinkenMovie * pMovie, char * pFilename );
int BlinkenMovieSaveBml( stBlinkenMovie * pMovie, char * pFilename );
int BlinkenMovieSaveBbm( stBlinkenMovie * pMovie, char * pFilename );
int BlinkenMovieSave( stBlinkenMovie * pMovie, char * pFilename );

void BlinkenMovieSend( stBlinkenMovie * pMovie, int udpSocket, etBlinkenProto proto );
//udp socket must be "connected"

stBlinkenMovie * BlinkenMovieReceive( int udpSocket, int timeout, etBlinkenProto * pProto );
//udp socket must be "bound" and should be "connected"
//after timeout ms of no reception, the movie is considered to be complete
//returns protocol in *pProto if pProto not NULL

#endif //#ifndef INC_BlinkenMovie

==> v0.5.2.zip: BlinkenMovie.h <==
/* BlinkenLib
 * version 0.5.2 date 2006-05-10
 * Copyright 2004-2006 Stefan Schuermans <1stein@schuermans.info>
 * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
 * a blinkenarea.org project
 */

#ifndef INC_BlinkenMovie
#define INC_BlinkenMovie

#include "BlinkenFrame.h"

#ifdef WIN32
#include <winsock2.h>
#else
#define SOCKET int
#define INVALID_SOCKET -1
#endif

typedef struct sBlinkenMovie stBlinkenMovie;

stBlinkenMovie * BlinkenMovieNew( int height, int width, int channels, int maxval );

stBlinkenMovie * BlinkenMovieClone( stBlinkenMovie * pSrcMovie );

void BlinkenMovieFree( stBlinkenMovie * pMovie );

int BlinkenMovieGetHeight( stBlinkenMovie * pMovie );
int BlinkenMovieGetWidth( stBlinkenMovie * pMovie );
int BlinkenMovieGetChannels( stBlinkenMovie * pMovie );
int BlinkenMovieGetMaxval( stBlinkenMovie * pMovie );
int BlinkenMovieGetDuration( stBlinkenMovie * pMovie );

int BlinkenMovieGetInfoCnt( stBlinkenMovie * pMovie );
char * BlinkenMovieGetInfoType( stBlinkenMovie * pMovie, int infoNo );
char * BlinkenMovieGetInfoData( stBlinkenMovie * pMovie, int infoNo );
void BlinkenMovieSetInfo( stBlinkenMovie * pMovie, int infoNo, char * pInfoType, char * pInfoData );
void BlinkenMovieInsertInfo( stBlinkenMovie * pMovie, int infoNo, char * pInfoType, char * pInfoData );
void BlinkenMovieAppendInfo( stBlinkenMovie * pMovie, char * pInfoType, char * pInfoData );
void BlinkenMovieDeleteInfo( stBlinkenMovie * pMovie, int infoNo );
void BlinkenMovieDeleteInfos( stBlinkenMovie * pMovie );

int BlinkenMovieGetFrameCnt( stBlinkenMovie * pMovie );
stBlinkenFrame * BlinkenMovieGetFrame( stBlinkenMovie * pMovie, int frameNo );
void BlinkenMovieSetFrame( stBlinkenMovie * pMovie, int frameNo, stBlinkenFrame * pFrame );
int BlinkenMovieInsertFrame( stBlinkenMovie * pMovie, int frameNo, stBlinkenFrame * pFrame );
int BlinkenMovieAppendFrame( stBlinkenMovie * pMovie, stBlinkenFrame * pFrame );
void BlinkenMovieDeleteFrame( stBlinkenMovie * pMovie, int frameNo );
void BlinkenMovieDeleteFrames( stBlinkenMovie * pMovie );

void BlinkenMovieResize( stBlinkenMovie * pMovie, int height, int width, int channels, int maxval );
void BlinkenMovieScale( stBlinkenMovie * pMovie, int height, int width );

char * BlinkenMovieToString( stBlinkenMovie * pMovie );

stBlinkenMovie * BlinkenMovieLoadBlm( char * pFilename );
stBlinkenMovie * BlinkenMovieLoadBmm( char * pFilename );
stBlinkenMovie * BlinkenMovieLoadBml( char * pFilename );
stBlinkenMovie * BlinkenMovieLoadBbm( char * pFilename );
stBlinkenMovie * BlinkenMovieLoad( char * pFilename );

int BlinkenMovieSaveBlm( stBlinkenMovie * pMovie, char * pFilename );
int BlinkenMovieSaveBmm( stBlinkenMovie * pMovie, char * pFilename );
int BlinkenMovieSaveBml( stBlinkenMovie * pMovie, char * pFilename );
int BlinkenMovieSaveBbm( stBlinkenMovie * pMovie, char * pFilename );
int BlinkenMovieSave( stBlinkenMovie * pMovie, char * pFilename );

void BlinkenMovieSend( stBlinkenMovie * pMovie, SOCKET udpSocket, etBlinkenProto proto );
//udp socket must be "connected"

stBlinkenMovie * BlinkenMovieReceive( SOCKET udpSocket, int timeout, etBlinkenProto * pProto );
//udp socket must be "bound" and should be "connected"
//after timeout ms of no reception, the movie is considered to be complete
//returns protocol in *pProto if pProto not NULL

#endif //#ifndef INC_BlinkenMovie
